@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Tmuxinator
   class Project
     include Tmuxinator::Util
@@ -41,16 +43,14 @@ module Tmuxinator
 
     def self.load(path, options = {})
       yaml = begin
-        raw_content = File.read(path)
-
         args = options[:args] || []
         @settings = parse_settings(args)
         @args = args
 
-        content = Erubis::Eruby.new(raw_content).result(binding)
-        YAML.safe_load(content, [], [], true)
-      rescue SyntaxError, StandardError => error
-        raise "Failed to parse config file: #{error.message}"
+        content = render_template(path, binding)
+        YAML.safe_load(content, aliases: true)
+             rescue SyntaxError, StandardError => error
+               raise "Failed to parse config file: #{error.message}"
       end
 
       new(yaml, options)
@@ -73,6 +73,7 @@ module Tmuxinator
         unless windows?
       raise "Your project file didn't specify a 'project_name'" \
         unless name?
+
       self
     end
 
@@ -103,7 +104,7 @@ module Tmuxinator
 
     def self.render_template(template, bndg)
       content = File.read(template)
-      Erubis::Eruby.new(content).result(bndg)
+      bndg.eval(Erubi::Engine.new(content).src)
     end
 
     def windows
@@ -239,8 +240,8 @@ module Tmuxinator
       !name.nil?
     end
 
-    def window(i)
-      "#{name}:#{i}"
+    def window(index)
+      "#{name}:#{index}"
     end
 
     def send_pane_command(cmd, window_index, _pane_index)
@@ -336,6 +337,44 @@ module Tmuxinator
       "#{tmux} kill-session -t #{name}"
     end
 
+    def enable_pane_titles?
+      yaml["enable_pane_titles"]
+    end
+
+    def tmux_set_pane_title_position(tmux_window_target)
+      command = set_window_option(tmux_window_target)
+      if pane_title_position? && pane_title_position_valid?
+        "#{command} pane-border-status #{yaml['pane_title_position']}"
+      else
+        "#{command} pane-border-status top"
+      end
+    end
+
+    def tmux_set_pane_title_format(tmux_window_target)
+      command = set_window_option(tmux_window_target)
+      if pane_title_format?
+        "#{command} pane-border-format \"#{yaml['pane_title_format']}\""
+      else
+        "#{command} pane-border-format \"\#{pane_index}: \#{pane_title}\""
+      end
+    end
+
+    def pane_title_position_not_valid_warning
+      print_warning(
+        "The specified pane title position " +
+        "\"#{yaml['pane_title_position']}\" is not valid. " +
+        "Please choose one of: top, bottom, or off."
+      )
+    end
+
+    def pane_titles_not_supported_warning
+      print_warning(
+        "You have enabled pane titles in your configuration, " +
+        "but the feature is not supported by your version of tmux.\n" +
+        "Please consider upgrading to a version that supports it (tmux >=2.6)."
+      )
+    end
+
     private
 
     def blank?(object)
@@ -349,9 +388,10 @@ module Tmuxinator
     def extract_tmux_config
       options_hash = {}
 
-      options_string = `#{show_tmux_options}`
-      options_string.encode!("UTF-8", invalid: :replace)
-      options_string.split("\n").map do |entry|
+      `#{show_tmux_options}`.
+        encode("UTF-8", invalid: :replace).
+        split("\n").
+        map do |entry|
         key, value = entry.split("\s")
         options_hash[key] = value
         options_hash
@@ -381,5 +421,28 @@ module Tmuxinator
     def wemux?
       yaml["tmux_command"] == "wemux"
     end
+
+    def pane_title_position?
+      yaml["pane_title_position"]
+    end
+
+    def pane_title_position_valid?
+      ["top", "bottom", "off"].include? yaml["pane_title_position"]
+    end
+
+    def pane_title_format?
+      yaml["pane_title_format"]
+    end
+
+    def print_warning(message)
+      yellow = '\033[1;33m'
+      no_color = '\033[0m'
+      msg = "WARNING: #{message}\n"
+      "printf \"#{yellow}#{msg}#{no_color}\""
+    end
+
+    def set_window_option(tmux_window_target)
+      "#{tmux} set-window-option -t #{tmux_window_target}"
+    end
   end
 end
