@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Tmuxinator
   class Window
     include Tmuxinator::Util
@@ -34,12 +36,16 @@ module Tmuxinator
       yaml["synchronize"] || false
     end
 
+    # The expanded, joined window root path
+    # Relative paths are joined to the project root
     def root
-      _yaml_root || _project_root
+      return _project_root unless _yaml_root
+
+      File.expand_path(_yaml_root, _project_root).shellescape
     end
 
     def _yaml_root
-      File.expand_path(yaml["root"]).shellescape if yaml["root"]
+      yaml["root"]
     end
 
     def _project_root
@@ -113,7 +119,7 @@ module Tmuxinator
 
     def tmux_new_window_command
       path = root? ? "#{Tmuxinator::Config.default_path_option} #{root}" : nil
-      "#{project.tmux} new-window #{path} -t #{tmux_window_target} #{tmux_window_name_option}"
+      "#{project.tmux} new-window #{path} -k -t #{tmux_window_target} #{tmux_window_name_option}"
     end
 
     def tmux_tiled_layout_command
