@@ -1,7 +1,10 @@
+# frozen_string_literal: true
+
 def yaml_load(file)
-  YAML.load(File.read(File.expand_path(file)))
+  YAML.safe_load(File.read(File.expand_path(file)))
 end
-FactoryGirl.define do
+
+FactoryBot.define do
   factory :project, class: Tmuxinator::Project do
     transient do
       file { yaml_load("spec/fixtures/sample.yml") }
@@ -41,6 +44,14 @@ FactoryGirl.define do
     initialize_with { Tmuxinator::Project.new(file) }
   end
 
+  factory :project_with_emoji_as_name, class: Tmuxinator::Project do
+    transient do
+      file { yaml_load("spec/fixtures/sample_emoji_as_name.yml") }
+    end
+
+    initialize_with { Tmuxinator::Project.new(file) }
+  end
+
   factory :project_with_literals_as_window_name, class: Tmuxinator::Project do
     transient do
       file { yaml_load("spec/fixtures/sample_literals_as_window_name.yml") }
@@ -96,4 +107,12 @@ FactoryGirl.define do
 
     initialize_with { Tmuxinator::Project.new(file) }
   end
+
+  factory :project_with_alias, class: Tmuxinator::Project do
+    transient do
+      file { "spec/fixtures/sample_alias.yml" }
+    end
+
+    initialize_with { Tmuxinator::Project.load(file) }
+  end
 end
