@@ -1,31 +1,44 @@
+# frozen_string_literal: true
+
 require "spec_helper"
 
 describe Tmuxinator::Project do
-  let(:project) { FactoryGirl.build(:project) }
+  let(:project) { FactoryBot.build(:project) }
   let(:project_with_custom_name) do
-    FactoryGirl.build(:project_with_custom_name)
+    FactoryBot.build(:project_with_custom_name)
   end
   let(:project_with_number_as_name) do
-    FactoryGirl.build(:project_with_number_as_name)
+    FactoryBot.build(:project_with_number_as_name)
+  end
+  let(:project_with_emoji_as_name) do
+    FactoryBot.build(:project_with_emoji_as_name)
   end
   let(:project_with_literals_as_window_name) do
-    FactoryGirl.build(:project_with_literals_as_window_name)
+    FactoryBot.build(:project_with_literals_as_window_name)
   end
   let(:project_with_deprecations) do
-    FactoryGirl.build(:project_with_deprecations)
+    FactoryBot.build(:project_with_deprecations)
   end
   let(:project_with_force_attach) do
-    FactoryGirl.build(:project_with_force_attach)
+    FactoryBot.build(:project_with_force_attach)
   end
   let(:project_with_force_detach) do
-    FactoryGirl.build(:project_with_force_detach)
+    FactoryBot.build(:project_with_force_detach)
   end
 
-  let(:wemux_project) { FactoryGirl.build(:wemux_project) }
-  let(:noname_project) { FactoryGirl.build(:noname_project) }
-  let(:noroot_project) { FactoryGirl.build(:noroot_project) }
+  let(:wemux_project) { FactoryBot.build(:wemux_project) }
+  let(:noname_project) { FactoryBot.build(:noname_project) }
+  let(:noroot_project) { FactoryBot.build(:noroot_project) }
   let(:nameless_window_project) do
-    FactoryGirl.build(:nameless_window_project)
+    FactoryBot.build(:nameless_window_project)
+  end
+
+  let(:project_with_alias) do
+    FactoryBot.build(:project_with_alias)
+  end
+
+  it "should include Hooks" do
+    expect(project).to be_kind_of(Tmuxinator::Hooks::Project)
   end
 
   describe "#initialize" do
@@ -55,12 +68,21 @@ describe Tmuxinator::Project do
         expect(rendered).to_not include("sample")
       end
     end
+
+    context "with alias" do
+      it "renders the tmux config" do
+        rendered = project_with_alias.render
+        expect(rendered).to_not be_empty
+        expect(rendered).to include("alias_is_working")
+      end
+    end
   end
 
   describe "#tmux_has_session?" do
     context "no active sessions" do
       before do
-        cmd = "#{project.tmux_command} ls 2> /dev/null"
+        tmux = project.tmux_command
+        cmd = "#{tmux} -f ~/.tmux.mac.conf -L foo ls 2> /dev/null"
         resp = ""
         call_tmux_ls = receive(:`).with(cmd).at_least(:once).and_return(resp)
 
@@ -74,7 +96,7 @@ describe Tmuxinator::Project do
 
     context "active sessions" do
       before do
-        cmd = "#{project.tmux_command} ls 2> /dev/null"
+        cmd = "#{project.tmux} ls 2> /dev/null"
         resp = ""\
           "foo: 1 window (created Sun May 25 10:12:00 1986) [0x0] (detached)\n"\
           "bar: 1 window (created Sat Sept 01 00:00:00 1990) [0x0] (detached)"
@@ -161,19 +183,47 @@ describe Tmuxinator::Project do
       end
     end
 
+    context "as emoji" do
+      it "will gracefully handle a name given as an emoji" do
+        rendered = project_with_emoji_as_name
+        # needs to allow for \\ present in shellescape'd project name
+        expect(rendered.name).to match(/^\\*🍩/)
+      end
+    end
+
     context "window as non-string literal" do
       it "will gracefully handle a window name given as a non-string literal" do
         rendered = project_with_literals_as_window_name
         expect(rendered.windows.map(&:name)).to match_array(
           %w(222 222333 111222333444555666777 222.3 4e5 4E5
-             true false nil // /sample/))
+             true false nil // /sample/)
+        )
       end
     end
   end
 
   describe "#pre_window" do
-    it "gets the pre_window command" do
-      expect(project.pre_window).to eq "rbenv shell 2.0.0-p247"
+    subject(:pre_window) { project.pre_window }
+
+    context "pre_window in yaml is string" do
+      before { project.yaml["pre_window"] = "mysql.server start" }
+
+      it "returns the string" do
+        expect(pre_window).to eq("mysql.server start")
+      end
+    end
+
+    context "pre_window in yaml is Array" do
+      before do
+        project.yaml["pre_window"] = [
+          "mysql.server start",
+          "memcached -d"
+        ]
+      end
+
+      it "joins array using ;" do
+        expect(pre_window).to eq("mysql.server start; memcached -d")
+      end
     end
 
     context "with deprecations" do
@@ -268,42 +318,53 @@ describe Tmuxinator::Project do
   end
 
   describe "#get_pane_base_index" do
-    it "extracts the pane_base_index from tmux_options" do
-      allow(project).to \
-        receive_messages(show_tmux_options: tmux_config(pane_base_index: 3))
+    it "extracts pane-base-index from the global tmux window options" do
+      allow_any_instance_of(Kernel).to receive(:`).
+        with(Regexp.new("tmux.+ show-window-option -g pane-base-index")).
+        and_return("pane-base-index 3\n")
 
       expect(project.get_pane_base_index).to eq("3")
     end
   end
 
   describe "#get_base_index" do
-    it "extracts the base index from options" do
-      allow(project).to \
-        receive_messages(show_tmux_options: tmux_config(base_index: 1))
+    it "extracts base-index from the global tmux options" do
+      allow_any_instance_of(Kernel).to receive(:`).
+        with(Regexp.new("tmux.+ show-option -g base-index")).
+        and_return("base-index 1\n")
 
       expect(project.get_base_index).to eq("1")
     end
   end
 
   describe "#base_index" do
-    context "pane base index present" do
+    context "when pane_base_index is 1 and base_index is unset" do
       before do
         allow(project).to receive_messages(get_pane_base_index: "1")
+        allow(project).to receive_messages(get_base_index: nil)
+      end
+
+      it "gets the tmux default of 0" do
+        expect(project.base_index).to eq(0)
+      end
+    end
+
+    context "base index present" do
+      before do
         allow(project).to receive_messages(get_base_index: "1")
       end
 
-      it "gets the pane base index" do
+      it "gets the base index" do
         expect(project.base_index).to eq 1
       end
     end
 
-    context "pane base index no present" do
+    context "base index not present" do
       before do
-        allow(project).to receive_messages(get_pane_base_index: nil)
-        allow(project).to receive_messages(get_base_index: "0")
+        allow(project).to receive_messages(get_base_index: nil)
       end
 
-      it "gets the base index" do
+      it "defaults to 0" do
         expect(project.base_index).to eq 0
       end
     end
@@ -314,7 +375,7 @@ describe Tmuxinator::Project do
       it "gets the startup window from project config" do
         project.yaml["startup_window"] = "logs"
 
-        expect(project.startup_window).to eq("logs")
+        expect(project.startup_window).to eq("sample:logs")
       end
     end
 
@@ -322,7 +383,7 @@ describe Tmuxinator::Project do
       it "returns base index instead" do
         allow(project).to receive_messages(base_index: 8)
 
-        expect(project.startup_window).to eq 8
+        expect(project.startup_window).to eq("sample:8")
       end
     end
   end
@@ -332,7 +393,7 @@ describe Tmuxinator::Project do
       it "get the startup pane index from project config" do
         project.yaml["startup_pane"] = 1
 
-        expect(project.startup_pane).to eq(1)
+        expect(project.startup_pane).to eq("sample:0.1")
       end
     end
 
@@ -340,7 +401,7 @@ describe Tmuxinator::Project do
       it "returns the base pane instead" do
         allow(project).to receive_messages(pane_base_index: 4)
 
-        expect(project.startup_pane).to eq(4)
+        expect(project.startup_pane).to eq("sample:0.4")
       end
     end
   end
@@ -502,7 +563,7 @@ describe Tmuxinator::Project do
     let(:window) { project.windows.first.name }
 
     context "when first window has a name" do
-      it "returns command to start a new detatched session" do
+      it "returns command to start a new detached session" do
         expect(project.tmux_new_session_command).to eq command
       end
     end
@@ -511,7 +572,7 @@ describe Tmuxinator::Project do
       let(:project) { nameless_window_project }
       let(:command) { "#{project.tmux} new-session -d -s #{project.name} " }
 
-      it "returns command to for new detatched session without a window name" do
+      it "returns command to for new detached session without a window name" do
         expect(project.tmux_new_session_command).to eq command
       end
     end
@@ -523,14 +584,14 @@ describe Tmuxinator::Project do
     let(:session) { project.name }
 
     context "when first window has a name" do
-      it "returns command to start a new detatched session" do
+      it "returns command to start a new detached session" do
         expect(project.tmux_kill_session_command).to eq command
       end
     end
   end
 
   describe "::load" do
-    let(:path) { File.expand_path("../../../fixtures/sample.yml", __FILE__) }
+    let(:path) { File.expand_path("../../fixtures/sample.yml", __dir__) }
     let(:options) { {} }
 
     it "should raise if the project file doesn't parse" do
@@ -541,7 +602,7 @@ describe Tmuxinator::Project do
       expect(File).to receive(:read).with(path) { bad_yaml }
       expect do
         described_class.load(path, options)
-      end.to raise_error RuntimeError, %r{Failed.to.parse.config.file}
+      end.to raise_error RuntimeError, /\AFailed to parse config file: .+\z/
     end
 
     it "should return an instance of the class if the file loads" do
@@ -564,7 +625,7 @@ describe Tmuxinator::Project do
 
   describe "#validate!" do
     it "should raise if there are no windows defined" do
-      nowindows_project = FactoryGirl.build(:nowindows_project)
+      nowindows_project = FactoryBot.build(:nowindows_project)
       expect do
         nowindows_project.validate!
       end.to raise_error RuntimeError, %r{should.include.some.windows}
@@ -576,4 +637,77 @@ describe Tmuxinator::Project do
       end.to raise_error RuntimeError, %r{didn't.specify.a.'project_name'}
     end
   end
+
+  describe "#pane_titles" do
+    before do
+      allow(project).to receive(:tmux).and_return "tmux"
+    end
+
+    context "pane_titles not enabled" do
+      before { project.yaml["enable_pane_titles"] = false }
+
+      it "returns false" do
+        expect(project.enable_pane_titles?).to be false
+      end
+    end
+
+    context "pane_titles enabled" do
+      before { project.yaml["enable_pane_titles"] = true }
+
+      it "returns true" do
+        expect(project.enable_pane_titles?).to be true
+      end
+    end
+
+    context "pane_title_position not configured" do
+      before { project.yaml["pane_title_position"] = nil }
+
+      it "configures a default position of top" do
+        expect(project.tmux_set_pane_title_position("x")).to eq(
+          "tmux set-window-option -t x pane-border-status top"
+        )
+      end
+    end
+
+    context "pane_title_position configured" do
+      before { project.yaml["pane_title_position"] = "bottom" }
+
+      it "configures a position of bottom" do
+        expect(project.tmux_set_pane_title_position("x")).to eq(
+          "tmux set-window-option -t x pane-border-status bottom"
+        )
+      end
+    end
+
+    context "pane_title_position invalid" do
+      before { project.yaml["pane_title_position"] = "other" }
+
+      it "configures the default position" do
+        expect(project.tmux_set_pane_title_position("x")).to eq(
+          "tmux set-window-option -t x pane-border-status top"
+        )
+      end
+    end
+
+    context "pane_title_format not configured" do
+      before { project.yaml["pane_title_format"] = nil }
+
+      it "configures a default format" do
+        resp = ""\
+          "tmux set-window-option -t x pane-border-format"\
+          " \"\#{pane_index}: \#{pane_title}\""
+        expect(project.tmux_set_pane_title_format("x")).to eq(resp)
+      end
+    end
+
+    context "pane_title_format configured" do
+      before { project.yaml["pane_title_format"] = " [ #T ] " }
+
+      it "configures the provided format" do
+        expect(project.tmux_set_pane_title_format("x")).to eq(
+          'tmux set-window-option -t x pane-border-format " [ #T ] "'
+        )
+      end
+    end
+  end
 end
