@@ -1,6 +1,9 @@
+# frozen_string_literal: true
+
 require "coveralls"
-require "simplecov"
 require "pry"
+require "simplecov"
+require "xdg"
 
 formatters = [
   SimpleCov::Formatter::HTMLFormatter,
@@ -12,9 +15,9 @@ SimpleCov.start do
 end
 
 require "tmuxinator"
-require "factory_girl"
+require "factory_bot"
 
-FactoryGirl.find_definitions
+FactoryBot.find_definitions
 
 # Custom Matchers
 require_relative "matchers/pane_matcher"
@@ -38,7 +41,7 @@ def capture_io
 
   yield
 
-  return captured_stdout.string, captured_stderr.string
+  [captured_stdout.string, captured_stderr.string]
 ensure
   $stdout = orig_stdout
   $stderr = orig_stderr
